@@ -1,5 +1,4 @@
 from django import forms
-from django.utils.encoding import smart_text
 from django.utils.text import capfirst
 from django.utils.translation import gettext_lazy as _
 
@@ -8,11 +7,12 @@ from haystack.constants import DEFAULT_ALIAS
 from haystack.query import EmptySearchQuerySet, SearchQuerySet
 from haystack.utils import get_model_ct
 from haystack.utils.app_loading import haystack_get_model
+from django.utils.encoding import smart_str
 
 
 def model_choices(using=DEFAULT_ALIAS):
     choices = [
-        (get_model_ct(m), capfirst(smart_text(m._meta.verbose_name_plural)))
+        (get_model_ct(m), capfirst(smart_str(m._meta.verbose_name_plural)))
         for m in connections[using].get_unified_index().get_indexed_models()
     ]
     return sorted(choices, key=lambda x: x[1])
